@@ -1,4 +1,4 @@
-#' Tweaks a future function by adjusting its default arguments
+#' Tweak a future function by adjusting its default arguments
 #'
 #' @param strategy An existing future function or the name of one.
 #' @param \dots Named arguments to replace the defaults of existing
@@ -44,7 +44,7 @@ tweak.character <- function(strategy, ..., penvir = parent.frame()) {
   }
 
   ## Sanity check
-  stopifnot(is.function(strategy))
+  stop_if_not(is.function(strategy))
 
   tweak(strategy, ..., penvir = penvir)
 }
@@ -77,15 +77,6 @@ tweak.future <- function(strategy, ..., penvir = parent.frame()) {
   ## Tweak arguments
   formals <- names(formals(strategy))
 
-  ## DEFUNCT
-  if ("workers" %in% formals) {
-    for (name in c("maxCores", "cluster")) {
-      if (name %in% names) {
-        .Defunct(msg = sprintf("Argument '%s' has been renamed to 'workers'. Please update you script/code that uses the future package.", name))
-      }
-    }
-  }
-
   unknown <- NULL
   for (kk in seq_along(args)) {
     name <- names[kk]
